@@ -9,7 +9,6 @@ log = logging.getLogger(sys.modules[__name__].__name__)
 
 
 class ManualPollingCachePolicy(CachePolicy):
-
     def __init__(self, config_fetcher, config_cache):
         self._config_fetcher = config_fetcher
         self._config_cache = config_cache
@@ -25,8 +24,17 @@ class ManualPollingCachePolicy(CachePolicy):
             self._lock.release_read()
 
     def force_refresh(self):
+        force_fetch = False
+
         try:
-            configuration_response = self._config_fetcher.get_configuration_json()
+            self._lock.acquire_read()
+            config = self._config_cache.get()
+            force_fetch = not bool(config)
+        finally:
+            self._lock.release_read()
+
+        try:
+            configuration_response = self._config_fetcher.get_configuration_json(force_fetch)
             if configuration_response.is_fetched():
                 configuration = configuration_response.json()
                 try:
@@ -38,7 +46,7 @@ class ManualPollingCachePolicy(CachePolicy):
         except HTTPError as e:
             log.error('Double-check your SDK Key at https://app.configcat.com/sdkkey.'
                       ' Received unexpected response: [%s]' % str(e.response))
-        except:
+        except Exception:
             log.exception(sys.exc_info()[0])
 
     def stop(self):
